
def printlist(add_to_list):
    list_grocries = []
    print "a list of things"
    list_groceries = ["milk", "bread", "carrot", "cheese", "butter"]
    list_groceries.append(add_to_list)
    return list_groceries
    

#printlist("cream")



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup
    
config = {
    'description' : 'Dungeon of Crow',
    'author' : 'Nicolas tarral',
    'url' : 'just local',
    'download_url' : 'local',
    'author_email' : 'nicolas@tarral.net',
    'version' : '0.1',
    'install_requires' : ['nose'],
    'packages' : ['dungeon'],
    'scripts' : ['bin/testprint.py'],
    'name' : 'dungeon'
}
 
setup(**config)
